export default {
    "index": 15,
    "lineNumber": 1,
    "column": 16,
    "message": "Binding eval in strict mode"
};